; Modification of mode9 with *split-global-disjunctions* t
; May 11 2010
; Chad E Brown
(setq *split-global-disjunctions* t) ; the only difference from mode9
(setq *call-period* 100)
(setq *minisat-timeout* 1)
(setq *exists-delay* 0)
(setq *forall-delay* 0)
(setq *defaultelt-delay* 30)
(setq *defaulteltinst-delay* 0)
(setq *confr-diff-delay* 0)
(setq *confr-same1-delay* 0)
(setq *confr-same2-delay* 0)
(setq *enum-start* 10)
(setq *enum-arrow* 10)
(setq *enum-o* 5)
(setq *enum-sort* 2)
(setq *enum-neg* 0)
(setq *enum-or* 100)
(setq *enum-false* 100)
(setq *enum-choice* 100)
(setq *enum-eq* 100)
